﻿using System.Collections.Generic;
using System.IO;
using System.Reflection;
using System.Runtime.InteropServices;
using System.Security.Cryptography;
using System.Text;
using System.Windows.Forms;

// Change this to match your program's normal namespace
namespace LogonShell
{
    public class IniFile   // Rev.11 Customized for LogonShell
    {
        public string Path { get; }
        string EXE = Assembly.GetExecutingAssembly().GetName().Name;
        public List<IniKey> Default { get; }

        [DllImport("kernel32", CharSet = CharSet.Unicode)]
        static extern long WritePrivateProfileString(string Section, string Key, string Value, string FilePath);

        [DllImport("kernel32", CharSet = CharSet.Unicode)]
        static extern int GetPrivateProfileString(string Section, string Key, string Default, StringBuilder RetVal, int Size, string FilePath);

        public IniFile(IniKey[] Default, string IniPath = null)
        {
            Path = new FileInfo(IniPath ?? EXE + ".ini").FullName;
            this.Default = new List<IniKey>(Default);
        }

        public string Read(string Key, string Section = null)
        {
            var RetVal = new StringBuilder(255);
            GetPrivateProfileString(Section ?? EXE, Key, "", RetVal, 255, Path);
            return RetVal.ToString();
        }

        public string Read(IniKey iniKey)
        {
            return Read(iniKey.Key, iniKey.Section);
        }
        public string Read(int KeyId)
        {
            return Read(Default[KeyId]);
        }
        public void ReadKey(IniKey iniKey)
        {
            iniKey.Value = Read(iniKey.Key, iniKey.Section);
        }
        public void ReadKey(int KeyId)
        {
            Default[KeyId].Value = Read(Default[KeyId]);
        }

        public void Write(string Key, string Value, string Section = null)
        {
            WritePrivateProfileString(Section ?? EXE, Key, Value, Path);
        }
        public void Write(IniKey iniKey)
        {
            Write(iniKey.Key, iniKey.Value, iniKey.Section);
        }
        public void Write(int KeyId)
        {
            Write(Default[KeyId]);
        }

        public void DeleteKey(string Key, string Section = null)
        {
            Write(Key, null, Section ?? EXE);
        }

        public void DeleteSection(string Section = null)
        {
            Write(null, null, Section ?? EXE);
        }

        public bool KeyExists(string Key, string Section = null)
        {
            return Read(Key, Section).Length > 0;
        }
        public bool KeyExists(IniKey iniKey)
        {
            return KeyExists(iniKey.Key, iniKey.Section);
        }
        public bool KeyExists(int KeyId)
        {
            return KeyExists(Default[KeyId]);
        }

        public void Reset()
        {
            foreach (IniKey iniKey in Default)
                Write(iniKey);
        }

        public void Update()
        {
            Write(Default[0]); // Overwrite the version
            foreach (IniKey iniKey in Default)
                if (!KeyExists(iniKey))
                    Write(iniKey);
        }
    }

    public class IniKey
    {
        public string Key { get; set; }
        public string Value { get; set; }
        public string Section { get; set; }

        public IniKey(string Key, string Value = null, string Section = null)
        {
            this.Key = Key;
            this.Value = Value;
            this.Section = Section;
        }
    }
}