﻿using LogonShell.Properties;
using System.IO;
using System.Reflection;
using System.Runtime.InteropServices;
using System.Text;
namespace LogonShell {
    public class Settings
    {
        public static string ProgramVersion = "RC3";
        private static IniFile SettingsFile;
        private static IniFile LocaleFile;
        public static string[] args { get; set; }

        public static void Initialize(string[] argsv)
        {
            SettingsFile = new IniFile(Default);
            LocaleFile = new IniFile(Locale, Read(4));
            args = argsv;
        }
        public static string Read(int id, bool IsLocale = false)
        {
            return (IsLocale) ? LocaleFile.Read(id) : SettingsFile.Read(id);
        }
        public static bool KeyExists(int id, bool IsLocale = false)
        {
            return (IsLocale) ? LocaleFile.KeyExists(id) : SettingsFile.KeyExists(id);
        }



        public static IniKey[] Default { get; } = new IniKey[] {
            new IniKey("Version", ProgramVersion, "Program"),
            new IniKey("ResetSettings", "False", "Main"),
            new IniKey("ResetLocale", "False", "Main"),
            new IniKey("Banner", "theme\\banner.png", "Main"),
            new IniKey("Localisation", "theme\\locale.ini", "Main"),
            new IniKey("Type", "Multi", "Background"),
            new IniKey("Color", "#1d5c8c", "Background"),
            new IniKey("Image", "theme\\bg.logo.png", "Background"),
            new IniKey("ShowOnMulti", "True", "Background"),
            new IniKey("X", "12", "Background"),
            new IniKey("Y", "12", "Background"),
            new IniKey("Width", "600", "Background"),
            new IniKey("ScaleFactor", "0", "Background"),
            new IniKey("ScaleType", "X", "Background"),
            new IniKey("UseKeySequence", "False", "KeySequence"),
            new IniKey("Icon", "theme\\keyboard.icon.png", "KeySequence"),
            new IniKey("Type", "ListLast", "Login"),
            new IniKey("IsCancelEnabled", "True", "Login"),
            new IniKey("ButtonX", "None", "Login"),
            new IniKey("Image", "theme\\loading.gif", "Loading"),
            new IniKey("ReverseAtEnd", "False", "Loading"),
            new IniKey("ShutdownIcon", "theme\\shutdown.icon.png", "Shutdown"),
            new IniKey("Error", "theme\\messagebox.error.ico", "MessageBox"),
            new IniKey("Warning", "theme\\messagebox.warning.ico", "MessageBox"),
            new IniKey("Hint", "TryFirst", "Login"),
            new IniKey("Mode", "LogonUI", "Main"),
            new IniKey("FgColor", "Default", "Main"),
            new IniKey("BgColor", "Default", "Main"),
            new IniKey("Theme", "Classic", "Main"),
            new IniKey("RestartIcon", "theme\\shutdown.icon.png", "Shutdown"),
            new IniKey("SleepIcon", "theme\\sleep.icon.png", "Shutdown")
        };




        public static IniKey[] Locale { get; } = new IniKey[]
        {
            new IniKey("Version", ProgramVersion, "Program"),
            new IniKey("buttonOK", "OK", "Main"),
            new IniKey("buttonCancel", "Cancel", "Main"),
            new IniKey("Title", "Welcome to Windows", "KeySequence"),
            new IniKey("Text", "Press the Windows key to start.", "KeySequence"),
            new IniKey("Title", "Log On to Windows", "Login"),
            new IniKey("labelPassword", "Password:", "Login"),
            new IniKey("labelUsername", "User name:", "Login"),
            new IniKey("buttonOptions", "Options", "Login"),
            new IniKey("buttonShutdown", "Shutdown...", "Login"),
            new IniKey("Title", "Please Wait...", "Loading"),
            new IniKey("Text", "Applying your personal settings...", "Loading"),
            new IniKey("Title", "Shut down Windows", "Shutdown"),
            new IniKey("Text", "What do you want the computer to do?", "Shutdown"),
            new IniKey("ShutdownText", "Shutting down Windows...", "Loading"),
            new IniKey("Name1", "Shut down", "Shutdown"),
            new IniKey("Name2", "Restart", "Shutdown"),
            new IniKey("Name3", "Stand by", "Shutdown"),
            new IniKey("Desc1", "Ends your session and shuts down Windows so you can safely turn off power.", "Shutdown"),
            new IniKey("Desc2", "Ends your session, shuts down Windows, and starts Windows again.", "Shutdown"),
            new IniKey("Desc3", "Maintains your session, keeping the computer running on low power with data still in memory.", "Shutdown"),
            new IniKey("ErrorTitle", "Logon Message", "Login"),
            new IniKey("ErrorText", "The system could not log you on. Make sure your User name and domain are correct, then type your password again.  Letters in passwords must be typed using the correct case. Make sure that Caps Lock is not accidentally on.", "Login"),
            new IniKey("ErrorTitle", "Error", "Main")
        };
    }
}